==> Glossary-0.6.7.tar.gz: Glossary/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Glossary / Dictionary / FAQ module
# Version: 0.6.6, SjG
# http://dev.cmsmadesimple.org/projects/glossary
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2009 by Ted Kulp (ted@cmsmadesimple.org)
# http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$db = &$this->GetDb();
		
// remove the database table
$dict = NewDataDictionary( $db );
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_term" );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_cat" );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_term_cat" );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_template" );
$dict->ExecuteSQLArray($sqlarray);

// remove the sequence
$db->DropSequence( cms_db_prefix()."module_glossary_term_seq" );
$db->DropSequence( cms_db_prefix()."module_glossary_cat_seq" );
$db->DropSequence( cms_db_prefix()."module_glossary_template_seq" );

// remove the permissions
$this->RemovePermission('Modify Glossary');

$this->RemovePreference('default_template');
$this->RemovePreference('default_single_term_template');
$this->RemovePreference('number_show');
$this->RemovePreference('filter_site');
$this->RemovePreference('filter_news');
$this->RemovePreference('show_single');
$this->RemovePreference('glossary_inline');
$this->RemovePreference('show_termids');
$this->RemovePreference('spining_chars');
$this->RemovePreference('glossary_page');
		
// put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled'));

# EOF
?>

==> Glossary-1.0.tar.gz: Glossary/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Glossary / Dictionary / FAQ module
# Version: 0.6.6, SjG
# http://dev.cmsmadesimple.org/projects/glossary
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2009 by Ted Kulp (ted@cmsmadesimple.org)
# http://www.cmsmadesimple.org
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$db = &$this->GetDb();
		
// remove the database table
$dict = NewDataDictionary( $db );
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_term" );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_cat" );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_term_cat" );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_glossary_template" );
$dict->ExecuteSQLArray($sqlarray);

// remove the sequence
$db->DropSequence( cms_db_prefix()."module_glossary_term_seq" );
$db->DropSequence( cms_db_prefix()."module_glossary_cat_seq" );
$db->DropSequence( cms_db_prefix()."module_glossary_template_seq" );

// remove the permissions
$this->RemovePermission('Modify Glossary');

$this->RemovePreference();

// put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled'));

# EOF
?>
